==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorppur/settlement/service/IPurchaseSettlementService.java <==
package com.ejianc.business.proequipmentcorppur.settlement.service;

import com.ejianc.business.promaterial.settlement.vo.SettlementVO;
import com.ejianc.business.proequipmentcorppur.purchase.bean.PurchaseContractClauseEntity;
import com.ejianc.business.proequipmentcorppur.purchase.bean.PurchaseContractEntity;
import com.ejianc.business.proequipmentcorppur.settlement.bean.PurchaseSettlementEntity;
import com.ejianc.business.proequipmentcorppur.settlement.vo.ContractSettlementRecordVO;
import com.ejianc.business.proequipmentcorppur.settlement.vo.PurchaseSettlementVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 设备采购结算表
 *
 * @author generator
 */
public interface IPurchaseSettlementService extends IBaseService<PurchaseSettlementEntity> {

    CommonResponse<PurchaseSettlementVO> saveOrUpdate(PurchaseSettlementVO saveOrUpdateVO);

    CommonResponse<Map> getDateMny(Long contractId);

    CommonResponse<String> delete(List<PurchaseSettlementVO> vos);

    boolean pushBillToSupCenter(PurchaseSettlementEntity entity, String billTypeCode);
    CommonResponse<String> updatePushBill(PurchaseSettlementEntity entity, String billTypeCode);
    String updateBillSupSignSyncInfo(HttpServletRequest request);
    boolean pushSettleToPool(PurchaseSettlementVO vo);

    boolean delSettleFromPool(Long id);

//    ExecutionVO targetCost(PurchaseSettlementVO settlementVO, String linkUrl);
//    SettlementRecordVO querySettleRecord(Long contractId);
    /*
    *参数控制集成方法
    */
    ParamsCheckVO checkParams(PurchaseSettlementVO vo);
    /*
    *合同金额控结算金额
    */
    List<ParamsCheckVO> checkParamsMny(PurchaseContractEntity contractEntity, PurchaseSettlementVO vo);

    ContractSettlementRecordVO queryDetailRecord(Long contractId);

    void updateContractPoolSettle(PurchaseSettlementVO vo, Boolean type);
}

==> ejc-proequipmentcorp-impl-3.0.0-20251013.062057-516-sources.jar: com/ejianc/business/proequipmentcorppur/settlement/service/IPurchaseSettlementService.java <==
package com.ejianc.business.proequipmentcorppur.settlement.service;

import com.ejianc.business.proequipmentcorppur.purchase.bean.PurchaseContractEntity;
import com.ejianc.business.proequipmentcorppur.settlement.bean.PurchaseSettlementEntity;
import com.ejianc.business.proequipmentcorppur.settlement.vo.ContractSettlementRecordVO;
import com.ejianc.business.proequipmentcorppur.settlement.vo.PurConSettleReportVO;
import com.ejianc.business.proequipmentcorppur.settlement.vo.PurchaseSettlementVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * 设备采购结算表
 *
 * @author generator
 */
public interface IPurchaseSettlementService extends IBaseService<PurchaseSettlementEntity> {

    CommonResponse<PurchaseSettlementVO> saveOrUpdate(PurchaseSettlementVO saveOrUpdateVO);

    CommonResponse<Map> getDateMny(Long contractId);

    CommonResponse<String> delete(List<PurchaseSettlementVO> vos);

    boolean pushBillToSupCenter(PurchaseSettlementEntity entity, String billTypeCode);
    CommonResponse<String> updatePushBill(PurchaseSettlementEntity entity, String billTypeCode);
    String updateBillSupSignSyncInfo(HttpServletRequest request);
    boolean pushSettleToPool(PurchaseSettlementVO vo);

    boolean delSettleFromPool(Long id);

//    ExecutionVO targetCost(PurchaseSettlementVO settlementVO, String linkUrl);
//    SettlementRecordVO querySettleRecord(Long contractId);
    /*
    *参数控制集成方法
    */
    ParamsCheckVO checkParams(PurchaseSettlementVO vo);
    /*
    *合同金额控结算金额
    */
    List<ParamsCheckVO> checkParamsMny(PurchaseContractEntity contractEntity, PurchaseSettlementVO vo);

    ContractSettlementRecordVO queryDetailRecord(Long contractId);

    void updateContractPoolSettle(PurchaseSettlementVO vo, Boolean type);

    Map<String, Object> count(Map<String, Object> paramMap);

    List<PurConSettleReportVO> pageList(Map<String, Object> paramMap);
}
